@@ -180,13 +180,14 @@ class SchemaMapperTests(FactoryTestCase):
         bar_type = AttrTypeFactory.create(qname="bar")
         foo_type = AttrTypeFactory.create(qname="foo")
 
-        bar = ExtensionFactory.create(bar_type)
-        double = ExtensionFactory.create(bar_type)
-        foo = ExtensionFactory.create(foo_type)
+        bar = ExtensionFactory.create(bar_type, tag=Tag.RESTRICTION)
+        double = ExtensionFactory.create(bar_type, tag=Tag.RESTRICTION)
+        foo = ExtensionFactory.create(foo_type, tag=Tag.EXTENSION)
 
         mock_children_extensions.return_value = [bar, double, foo]
         self_ext = ExtensionFactory.reference(
             qname="{xsdata}something",
+            tag=Tag.ELEMENT,
             restrictions=Restrictions(min_occurs=1, max_occurs=1),
         )
 
@@ -199,7 +200,9 @@ class SchemaMapperTests(FactoryTestCase):
 
     def test_element_children(self):
         sequence_one = Sequence(elements=[Element(), Element()])
+        sequence_one.index = 1
         sequence_two = Sequence(max_occurs=2, elements=[Element(), Element()])
+        sequence_two.index = 2
         restriction = Restriction(
             enumerations=[Enumeration(value=x) for x in "abc"], sequence=sequence_two
         )
@@ -230,12 +233,13 @@ class SchemaMapperTests(FactoryTestCase):
         complex_type = ComplexType(
             sequence=Sequence(choices=[choice], min_occurs=0, max_occurs=3)
         )
+        complex_type.sequence.index = 2
         parent_restrictions = Restrictions.from_element(complex_type)
         children = SchemaMapper.element_children(complex_type, parent_restrictions)
 
         child, restrictions = next(children)
         expected = Restrictions(
-            min_occurs=0, max_occurs=3, sequential=True, choice=str(id(choice))
+            path=[("s", id(complex_type.sequence), 0, 3), ("c", id(choice), 1, 1)]
         )
         self.assertEqual(expected, restrictions)
 
@@ -250,15 +254,16 @@ class SchemaMapperTests(FactoryTestCase):
 
         item = ClassFactory.create(ns_map={"bk": "book"})
         children = SchemaMapper.children_extensions(complex_type, item)
-        expected = list(
-            map(
-                ExtensionFactory.create,
-                [
-                    AttrTypeFactory.create(qname=build_qname("book", "b")),
-                    AttrTypeFactory.create(qname=build_qname("book", "c")),
-                ],
-            )
-        )
+        expected = [
+            ExtensionFactory.create(
+                AttrTypeFactory.create(qname=build_qname("book", "b")),
+                tag=Tag.RESTRICTION,
+            ),
+            ExtensionFactory.create(
+                AttrTypeFactory.create(qname=build_qname("book", "c")),
+                tag=Tag.EXTENSION,
+            ),
+        ]
 
         self.assertIsInstance(children, GeneratorType)
         self.assertEqual(expected, list(children))
@@ -316,12 +321,6 @@ class SchemaMapperTests(FactoryTestCase):
         mock_build_class_attribute_types.assert_called_once_with(item, attribute)
         mock_element_namespace.assert_called_once_with(attribute, item.target_namespace)
 
-    def test_build_class_attribute_skip_prohibited(self):
-        item = ClassFactory.create(ns_map={"bar": "foo"})
-        attribute = Attribute(use=UseType.PROHIBITED)
-        SchemaMapper.build_class_attribute(item, attribute, Restrictions())
-        self.assertEqual(0, len(item.attrs))
-
     @mock.patch.object(Attribute, "attr_types", new_callable=mock.PropertyMock)
     @mock.patch.object(SchemaMapper, "build_inner_classes")
     def test_build_class_attribute_types(
