@@ -122,7 +122,7 @@ class NodeParserTests(TestCase):
 
         attrs = {QNames.XSI_TYPE: "bk:books"}
         ns_map = {"bk": "urn:books", "xsi": Namespace.XSI.uri}
-        parser.start(None, queue, objects, "doc", attrs, ns_map)
+        parser.start(None, queue, objects, "whatever", attrs, ns_map)
         actual = queue[0]
 
         self.assertEqual(1, len(queue))
@@ -184,7 +184,7 @@ class NodeParserTests(TestCase):
         objects = [("q", "result")]
         queue = []
         var = XmlVarFactory.create(xml_type=XmlType.TEXT, name="foo", qname="foo")
-        queue.append(PrimitiveNode(var, ns_map={}, derived_factory=DerivedElement))
+        queue.append(PrimitiveNode(var, {}, False, DerivedElement))
 
         self.assertTrue(parser.end(queue, objects, "author", "foobar", None))
         self.assertEqual(0, len(queue))
