@@ -10,6 +10,7 @@ from typing import Dict
 from typing import Iterator
 from typing import List
 from typing import Optional
+from typing import Tuple
 from typing import Type
 
 from xsdata.exceptions import CodeGenerationError
@@ -54,7 +55,7 @@ class Restrictions:
     :param pattern:
     :param explicit_timezone:
     :param nillable:
-    :param sequential:
+    :param sequence:
     :param tokens:
     :param format:
     :param choice:
@@ -75,10 +76,12 @@ class Restrictions:
     pattern: Optional[str] = field(default=None)
     explicit_timezone: Optional[str] = field(default=None)
     nillable: Optional[bool] = field(default=None)
-    sequential: Optional[bool] = field(default=None)
+    sequence: Optional[int] = field(default=None)
     tokens: Optional[bool] = field(default=None)
     format: Optional[str] = field(default=None)
-    choice: Optional[str] = field(default=None)
+    choice: Optional[int] = field(default=None)
+    group: Optional[int] = field(default=None)
+    path: List[Tuple[str, int, int, int]] = field(default_factory=list)
 
     @property
     def is_list(self) -> bool:
@@ -96,29 +99,20 @@ class Restrictions:
 
     def merge(self, source: "Restrictions"):
         """Update properties from another instance."""
-
         self.update(source)
 
-        min_occurs = source.min_occurs
-        max_occurs = source.max_occurs
-        is_list = max_occurs is not None and max_occurs > 1
+        self.path = source.path + self.path
+        self.sequence = self.sequence or source.sequence
+        self.choice = self.choice or source.choice
+        self.tokens = self.tokens or source.tokens
+        self.format = self.format or source.format
+        self.group = self.group or source.group
 
-        # Update the sequential flag if new value is true and restrictions indicate
-        # the field was and still is a list.
-        if source.sequential and (is_list or not self.is_list):
-            self.sequential = source.sequential
+        if self.min_occurs is None and source.min_occurs is not None:
+            self.min_occurs = source.min_occurs
 
-        self.choice = source.choice or self.choice
-        self.tokens = source.tokens or self.tokens
-        self.format = source.format or self.format
-
-        # Update min occurs if current value is None or the new value is more than one.
-        if self.min_occurs is None or (min_occurs is not None and min_occurs != 1):
-            self.min_occurs = min_occurs
-
-        # Update max occurs if current value is None or the new value is more than one.
-        if self.max_occurs is None or (max_occurs is not None and max_occurs != 1):
-            self.max_occurs = max_occurs
+        if self.max_occurs is None and source.max_occurs is not None:
+            self.max_occurs = source.max_occurs
 
     def update(self, source: "Restrictions"):
         keys = (
@@ -148,7 +142,6 @@ class Restrictions:
         Skip None or implied values, and optionally use the parent
         attribute types to convert relevant options.
         """
-
         result = {}
         sorted_types = converter.sort_types(types) if types else []
 
@@ -161,7 +154,13 @@ class Restrictions:
             result["required"] = True
 
         for key, value in asdict(self).items():
-            if value is None or key in ("choice", "min_occurs", "max_occurs"):
+            if value is None or key in (
+                "choice",
+                "group",
+                "min_occurs",
+                "max_occurs",
+                "path",
+            ):
                 continue
 
             if key.endswith("clusive") and types:
@@ -266,6 +265,10 @@ class Attr:
     def __post_init__(self):
         self.local_name = self.name
 
+    @property
+    def key(self) -> str:
+        return f"{self.tag}.{self.namespace}.{self.local_name}"
+
     @property
     def is_attribute(self) -> bool:
         """Return whether this attribute is derived from an xs:attribute or
@@ -298,6 +301,11 @@ class Attr:
         """Return whether this attribute is a list of values."""
         return self.restrictions.is_list
 
+    @property
+    def is_prohibited(self) -> bool:
+        """Return whether this attribute is prohibited."""
+        return self.restrictions.is_prohibited
+
     @property
     def is_nameless(self) -> bool:
         """Return whether this attribute has a local name that will be used
@@ -336,16 +344,14 @@ class Attr:
         xs:any."""
         return self.tag in (Tag.ANY_ATTRIBUTE, Tag.ANY)
 
+    @property
+    def is_any_type(self) -> bool:
+        return any(tp is object for tp in self.get_native_types())
+
     @property
     def native_types(self) -> List[Type]:
         """Return a list of all builtin data types."""
-        result = set()
-        for tp in self.types:
-            datatype = tp.datatype
-            if datatype:
-                result.add(datatype.type)
-
-        return list(result)
+        return list(set(self.get_native_types()))
 
     @property
     def user_types(self) -> Iterator[AttrType]:
@@ -371,16 +377,24 @@ class Attr:
             restrictions=self.restrictions.clone(),
         )
 
+    def get_native_types(self) -> Iterator[Type]:
+        for tp in self.types:
+            datatype = tp.datatype
+            if datatype:
+                yield datatype.type
+
 
 @dataclass(unsafe_hash=True)
 class Extension:
     """
     Model representation of a dataclass base class.
 
+    :param tag:
     :param type:
     :param restrictions:
     """
 
+    tag: str
     type: AttrType
     restrictions: Restrictions = field(hash=False)
 
@@ -395,14 +409,16 @@ class Extension:
 
 class Status(IntEnum):
     RAW = 0
-    FLATTENING = 10
-    FLATTENED = 11
-    SANITIZING = 20
-    SANITIZED = 21
-    RESOLVING = 30
-    RESOLVED = 31
-    FINALIZING = 40
-    FINALIZED = 41
+    UNGROUPING = 10
+    UNGROUPED = 11
+    FLATTENING = 20
+    FLATTENED = 21
+    SANITIZING = 30
+    SANITIZED = 31
+    RESOLVING = 40
+    RESOLVED = 41
+    FINALIZING = 50
+    FINALIZED = 51
 
 
 @dataclass
@@ -591,7 +607,6 @@ class Class:
             * Ignore inner class references
             * Ignore native types.
         """
-
         types = {ext.type for ext in self.extensions}
 
         for attr in self.attrs:
@@ -636,6 +651,7 @@ get_name = operator.attrgetter("name")
 get_qname = operator.attrgetter("qname")
 get_tag = operator.attrgetter("tag")
 get_restriction_choice = operator.attrgetter("restrictions.choice")
+get_restriction_sequence = operator.attrgetter("restrictions.sequence")
 get_slug = operator.attrgetter("slug")
 get_target_namespace = operator.attrgetter("target_namespace")
 is_enumeration = operator.attrgetter("is_enumeration")
