@@ -1,7 +1,11 @@
+import hashlib
 import io
 import json
 import os
+import pickle
+import tempfile
 from collections import defaultdict
+from pathlib import Path
 from typing import Callable
 from typing import Dict
 from typing import List
@@ -99,7 +103,21 @@ class SchemaTransformer:
         self.processed: List[str] = []
         self.preloaded: Dict = {}
 
-    def process(self, uris: List[str]):
+    def process(self, uris: List[str], cache: bool = False):
+        cache_file = self.get_cache_file(uris) if cache else None
+        if cache_file and cache_file.exists():
+            logger.info(f"Loading from cache {cache_file}")
+
+            self.classes = pickle.loads(cache_file.read_bytes())
+        else:
+            self.process_sources(uris)
+
+        if cache_file and not cache_file.exists():
+            cache_file.write_bytes(pickle.dumps(self.classes))
+
+        self.process_classes()
+
+    def process_sources(self, uris: List[str]):
         sources = defaultdict(list)
         for uri in uris:
             tp = self.classify_resource(uri)
@@ -110,7 +128,6 @@ class SchemaTransformer:
         self.process_dtds(sources[TYPE_DTD])
         self.process_xml_documents(sources[TYPE_XML])
         self.process_json_documents(sources[TYPE_JSON])
-        self.process_classes()
 
     def process_definitions(self, uris: List[str]):
         """Process a list of wsdl resources."""
@@ -153,7 +170,6 @@ class SchemaTransformer:
 
     def process_xml_documents(self, uris: List[str]):
         """Process a list of xml resources."""
-
         classes = []
         parser = TreeParser()
         location = os.path.dirname(uris[0]) if uris else ""
@@ -168,7 +184,6 @@ class SchemaTransformer:
 
     def process_json_documents(self, uris: List[str]):
         """Process a list of json resources."""
-
         classes = []
         name = self.config.output.package.split(".")[-1]
         dirname = os.path.dirname(uris[0]) if uris else ""
@@ -176,13 +191,16 @@ class SchemaTransformer:
         for uri in uris:
             input_stream = self.load_resource(uri)
             if input_stream:
-                data = json.load(io.BytesIO(input_stream))
-                logger.info("Parsing document %s", uri)
-                if isinstance(data, dict):
-                    data = [data]
+                try:
+                    data = json.load(io.BytesIO(input_stream))
+                    logger.info("Parsing document %s", uri)
+                    if isinstance(data, dict):
+                        data = [data]
 
-                for obj in data:
-                    classes.extend(DictMapper.map(obj, name, dirname))
+                    for obj in data:
+                        classes.extend(DictMapper.map(obj, name, dirname))
+                except ValueError as exc:
+                    logger.warning("JSON load failed for file: %s", uri, exc_info=exc)
 
         self.classes.extend(ClassUtils.reduce_classes(classes))
 
@@ -236,7 +254,6 @@ class SchemaTransformer:
 
     def parse_schema(self, uri: str, namespace: Optional[str]) -> Optional[Schema]:
         """Parse the given schema uri and return the schema tree object."""
-
         input_stream = self.load_resource(uri)
         if input_stream is None:
             return None
@@ -322,3 +339,9 @@ class SchemaTransformer:
             inner += sum(self.count_classes(cls.inner))
 
         return main, inner
+
+    @classmethod
+    def get_cache_file(cls, uris: List[str]) -> Path:
+        key = hashlib.md5("".join(uris).encode()).hexdigest()
+        tempdir = tempfile.gettempdir()
+        return Path(tempdir).joinpath(f"{key}.cache")
