@@ -44,7 +44,8 @@ class Converter(abc.ABC):
         """
         Convert any type to the converter dedicated type.
 
-        :raises ConverterError: if converter fails with and expected ValueError
+        :raises ConverterError: if converter fails with and expected
+            ValueError
         """
 
     @abc.abstractmethod
@@ -69,7 +70,8 @@ class ConverterFactory:
         """
         Attempt to convert a any value to one of the given types.
 
-        If all attempts fail return the value input value and issue a warning.
+        If all attempts fail return the value input value and issue a
+        warning.
 
         :return: The first successful converted value.
         """
@@ -158,7 +160,6 @@ class ConverterFactory:
         converters, fall back to str and issue a warning if there are
         not matches.
         """
-
         try:
             # Quick in and out, without checking the whole mro.
             return self.registry[datatype]
@@ -323,7 +324,7 @@ class DecimalConverter(Converter):
         if value.is_infinite():
             return str(value).replace("Infinity", "INF")
 
-        return str(value)
+        return f"{value:f}"
 
 
 class QNameConverter(Converter):
@@ -424,7 +425,6 @@ class EnumConverter(Converter):
     def match(
         cls, value: Any, values: Sequence, length: int, real: Any, **kwargs: Any
     ) -> bool:
-
         if isinstance(value, str) and isinstance(real, str):
             return value == real or " ".join(values) == real
 
