@@ -34,7 +34,8 @@ class JsonParser(AbstractParser):
 
     :param config: Parser configuration
     :param context: Model context provider
-    :param load_factory: Replace the default json.load call with another implementation
+    :param load_factory: Replace the default json.load call with another
+        implementation
     """
 
     config: ParserConfig = field(default_factory=ParserConfig)
@@ -74,7 +75,7 @@ class JsonParser(AbstractParser):
         try:
             origin = get_origin(clazz)
             list_type = False
-            if origin is List:
+            if origin is list:
                 list_type = True
                 args = get_args(clazz)
 
@@ -108,7 +109,6 @@ class JsonParser(AbstractParser):
 
     def bind_dataclass(self, data: Dict, clazz: Type[T]) -> T:
         """Recursively build the given model from the input dict data."""
-
         if set(data.keys()) == self.context.class_type.derived_keys:
             return self.bind_derived_dataclass(data, clazz)
 
@@ -162,7 +162,6 @@ class JsonParser(AbstractParser):
         keys = set(data.keys())
         max_score = -1.0
         for clazz in classes:
-
             if not self.context.class_type.is_model(clazz):
                 continue
 
@@ -223,7 +222,6 @@ class JsonParser(AbstractParser):
 
     def bind_text(self, meta: XmlMeta, var: XmlVar, value: Any) -> Any:
         """Bind text/tokens value entrypoint."""
-
         if var.is_elements:
             # Compound field we need to match the value to one of the choice elements
             check_subclass = self.context.class_type.is_model(value)
@@ -231,6 +229,9 @@ class JsonParser(AbstractParser):
             if choice:
                 return self.bind_text(meta, choice, value)
 
+            if value is None:
+                return value
+
             raise ParserError(
                 f"Failed to bind '{value}' "
                 f"to {meta.clazz.__qualname__}.{var.name} field"
@@ -252,7 +253,6 @@ class JsonParser(AbstractParser):
 
     def bind_complex_type(self, meta: XmlMeta, var: XmlVar, data: Dict) -> Any:
         """Bind data to a user defined dataclass."""
-
         if var.is_clazz_union:
             # Union of dataclasses
             return self.bind_best_dataclass(data, var.types)
@@ -275,7 +275,6 @@ class JsonParser(AbstractParser):
 
     def bind_derived_value(self, meta: XmlMeta, var: XmlVar, data: Dict) -> Any:
         """Bind derived element entry point."""
-
         qname = data["qname"]
         xsi_type = data["type"]
         params = data["value"]
@@ -291,8 +290,6 @@ class JsonParser(AbstractParser):
 
         if not isinstance(params, dict):
             value = self.bind_text(meta, var, params)
-        elif var.clazz:
-            value = self.bind_complex_type(meta, var, params)
         elif xsi_type:
             clazz: Optional[Type] = self.context.find_type(xsi_type)
 
@@ -300,6 +297,8 @@ class JsonParser(AbstractParser):
                 raise ParserError(f"Unable to locate xsi:type `{xsi_type}`")
 
             value = self.bind_dataclass(params, clazz)
+        elif var.clazz:
+            value = self.bind_complex_type(meta, var, params)
         else:
             value = self.bind_best_dataclass(params, meta.element_types)
 
