@@ -80,7 +80,6 @@ class ElementNode(XmlNode):
     def bind(
         self, qname: str, text: Optional[str], tail: Optional[str], objects: List
     ) -> bool:
-
         obj: Any = None
         if not self.xsi_nil or self.meta.nillable:
             params: Dict = {}
@@ -184,9 +183,9 @@ class ElementNode(XmlNode):
         """
         Add the given value to the params dictionary with the var name as key.
 
-        Wrap the value to a list if var is a list. If the var name already exists it
-        means we have a name conflict and the parser needs to lookup for any available
-        wildcard fields.
+        Wrap the value to a list if var is a list. If the var name
+        already exists it means we have a name conflict and the parser
+        needs to lookup for any available wildcard fields.
 
         :return: Whether the binding process was successful or not.
         """
@@ -213,7 +212,6 @@ class ElementNode(XmlNode):
         generic AnyElement instance. If the previous value is already a
         generic instance add the current value as a child object.
         """
-
         value = self.prepare_generic_value(qname, value, var)
 
         if var.list_element:
@@ -272,7 +270,6 @@ class ElementNode(XmlNode):
 
         Return if any data was bound.
         """
-
         var = self.meta.text
 
         if not var or (text is None and not self.xsi_nil):
@@ -370,16 +367,19 @@ class ElementNode(XmlNode):
         if var.clazz:
             return self.build_element_node(
                 var.clazz,
+                var.derived,
                 attrs,
                 ns_map,
                 position,
-                derived_factory if var.derived else None,
+                derived_factory,
                 xsi_type,
                 xsi_nil,
             )
 
         if not var.any_type and not var.is_wildcard:
-            return nodes.PrimitiveNode(var, ns_map, derived_factory)
+            return nodes.PrimitiveNode(
+                var, ns_map, self.meta.mixed_content, derived_factory
+            )
 
         datatype = DataType.from_qname(xsi_type) if xsi_type else None
         derived = var.derived or var.is_wildcard
@@ -396,10 +396,11 @@ class ElementNode(XmlNode):
         if clazz:
             node = self.build_element_node(
                 clazz,
+                derived,
                 attrs,
                 ns_map,
                 position,
-                derived_factory if derived else None,
+                derived_factory,
                 xsi_type,
                 xsi_nil,
             )
@@ -418,19 +419,22 @@ class ElementNode(XmlNode):
     def build_element_node(
         self,
         clazz: Type,
+        derived: bool,
         attrs: Dict,
         ns_map: Dict,
         position: int,
-        derived_factory: Optional[Type] = None,
+        derived_factory: Type,
         xsi_type: Optional[str] = None,
         xsi_nil: Optional[bool] = None,
     ) -> Optional[XmlNode]:
-
         meta = self.context.fetch(clazz, self.meta.namespace, xsi_type)
 
         if not meta or (meta.nillable and xsi_nil is False):
             return None
 
+        if xsi_type and not derived and not issubclass(meta.clazz, clazz):
+            derived = True
+
         return ElementNode(
             meta=meta,
             config=self.config,
@@ -438,7 +442,7 @@ class ElementNode(XmlNode):
             ns_map=ns_map,
             context=self.context,
             position=position,
-            derived_factory=derived_factory,
+            derived_factory=derived_factory if derived else None,
             xsi_type=xsi_type,
             xsi_nil=xsi_nil,
             mixed=self.meta.mixed_content,
