@@ -333,17 +333,17 @@ class XmlSerializer(AbstractSerializer):
         while index < stop:
             var = attrs[index]
 
-            if not var.sequential:
+            if var.sequence is None:
                 value = getattr(obj, var.name)
                 if value is not None or var.nillable:
                     yield var, value
                 index += 1
                 continue
 
-            indices = range(index + 1, stop)
-            end = next((i for i in indices if not attrs[i].sequential), stop)
-            sequence = attrs[index:end]
-            index = end
+            indices = range(index, stop)
+            end = next(i for i in indices[::-1] if attrs[i].sequence == var.sequence)
+            sequence = attrs[index : end + 1]
+            index = end + 1
             j = 0
 
             rolling = True
@@ -351,12 +351,17 @@ class XmlSerializer(AbstractSerializer):
                 rolling = False
                 for var in sequence:
                     values = getattr(obj, var.name)
-                    if j < len(values):
+                    if collections.is_array(values):
+                        if j < len(values):
+                            rolling = True
+                            value = values[j]
+                            if value is not None or var.nillable:
+                                yield var, value
+                    elif j == 0:
                         rolling = True
-                        value = values[j]
+                        if values is not None or var.nillable:
+                            yield var, values
 
-                        if value is not None or var.nillable:
-                            yield var, value
                 j += 1
 
     @classmethod
@@ -376,7 +381,8 @@ class XmlSerializer(AbstractSerializer):
         :param meta: Object metadata
         :param nillable: Is model nillable
         :param xsi_type: The true xsi:type of the object
-        :param ignore_optionals: Skip optional attributes with default value
+        :param ignore_optionals: Skip optional attributes with default
+            value
         :return:
         """
         for var in meta.get_attribute_vars():
@@ -410,8 +416,8 @@ class XmlSerializer(AbstractSerializer):
         QName(s) so they also get a special treatment.
 
         We can't do all the conversions in the writer because we would
-        need to carry the xml vars inside the writer. Instead of that
-        we do the easy encoding here and leave the qualified names for
+        need to carry the xml vars inside the writer. Instead of that we
+        do the easy encoding here and leave the qualified names for
         later.
         """
         if isinstance(value, (str, QName)) or var is None:
