@@ -196,24 +196,30 @@ class ClassFactory(Factory):
 
 class ExtensionFactory(Factory):
     counter = 65
+    tags = [Tag.ELEMENT, Tag.EXTENSION, Tag.RESTRICTION]
 
     @classmethod
     def create(
         cls,
         attr_type: Optional[AttrType] = None,
         restrictions: Optional[Restrictions] = None,
+        tag: Optional[str] = None,
         **kwargs: Any,
     ) -> Extension:
         return Extension(
+            tag=tag or random.choice(cls.tags),
             type=attr_type or AttrTypeFactory.create(**kwargs),
             restrictions=restrictions or Restrictions(),
         )
 
     @classmethod
     def reference(cls, qname: str, **kwargs: Any) -> Extension:
+        tag = kwargs.pop("tag", None)
         restrictions = kwargs.pop("restrictions", None)
         return cls.create(
-            AttrTypeFactory.create(qname=qname, **kwargs), restrictions=restrictions
+            AttrTypeFactory.create(qname=qname, **kwargs),
+            tag=tag,
+            restrictions=restrictions,
         )
 
     @classmethod
@@ -375,7 +381,7 @@ class XmlVarFactory(Factory):
         any_type: bool = False,
         required: bool = False,
         nillable: bool = False,
-        sequential: bool = False,
+        sequence: Optional[int] = None,
         list_element: bool = False,
         default: Optional[Any] = None,
         xml_type: str = XmlType.ELEMENT,
@@ -385,7 +391,6 @@ class XmlVarFactory(Factory):
         prefix: str = "field_",
         **kwargs: Any,
     ) -> XmlVar:
-
         name = name or f"{prefix}{cls.next_letter()}"
 
         if qname is None:
@@ -415,7 +420,7 @@ class XmlVarFactory(Factory):
             any_type=any_type,
             required=required,
             nillable=nillable,
-            sequential=sequential,
+            sequence=sequence,
             list_element=list_element,
             default=default,
             xml_type=xml_type,
@@ -444,7 +449,6 @@ class XmlMetaFactory(Factory):
         any_attributes: Optional[Sequence[XmlVar]] = None,
         **kwargs: Any,
     ) -> XmlMeta:
-
         if qname is None:
             qname = clazz.__name__
 
@@ -495,7 +499,6 @@ class DtdAttributeFactory(Factory):
         values: Optional[List[str]] = None,
         **kwargs: Any,
     ) -> DtdAttribute:
-
         if name is None:
             name = f"attribute_{cls.next_letter()}"
 
@@ -563,7 +566,6 @@ class DtdElementFactory(Factory):
         ns_map: Optional[Dict] = None,
         **kwargs: Any,
     ) -> DtdElement:
-
         if name is None:
             name = f"element_{cls.next_letter()}"
 
